function [util,R] = mcmc_logit_mnl_kl10(value,expUmax,chy);

% logistic model
% for sampling the utilities and the indicators for the mixture error term
% from any model, where lexp=exp(structural part of the mixed effects model) is input

% input:
%   K .. . number of components in the mixture approximation
%   specopt  ..  0 
%   chy .. binary data labelled 0/1 (0 is reference), T times N
%   value .. = structural part of the model, T times N

% output:
%   util .. utilities - 1. data augentation
%   epsmean ... mean of the error fixed according to the indicators R, T x N
%   epsvar ... fixed error variances according to the indicators R, T x N


%   R .. indicators for the error - 2. data augmentation

T=size(chy,1);
N=size(chy,2);
K=10; % numbr of components fixed at 10

% 1. generating the utilities

V = rand(T,N);

lexp=exp(value);
 
util = -log(expUmax - log(V)./lexp.*(1-chy));

% 2. sampling the indicators

[smean,svar,eta]=define_normmix_kl10;

 
% loglikelihood  beide Arten liefern gleiche loglik getestet 2.3.05
% 1. Art: K x T x N
% for k=1:K,
%    llh(k,:,:) = -.5*(log(2*pi*svar(k))) - .5/svar(k)*(y-value-smean(k)).^2;   
% end

% 2. Art: K x (T*N) ist schneller
for i=1:N,
   yhelp=util(:,i)'; valuehelp = value(:,i)';
   llhlarge(:,1+(i-1)*T:i*T) = -.5*(log(2*pi*svar(:,ones(1,T)))) - .5./svar(:,ones(1,T)).*(yhelp(ones(K,1),:)-valuehelp(ones(K,1),:)-smean(:,ones(1,T))).^2;   
end

maxl = max(llhlarge);  % 1 x (T*N)
lh = exp(llhlarge - maxl(ones(1,K),:,:));  % K x (T*N)

p = eta(:,ones(1,T*N)).*lh; 
ss = sum(p,1);
p = p./ss(ones(1,K),:); % K x (T*N)

rnd = rand(1,T*N);
R = (sum(cumsum(p,1)< rnd(ones(K,1),:),1) + 1);      % sampling
R = reshape(R,T,N);
