function [gam,gampm,gampc] = simgamlogit(gam,Zgam,sst,prmgam,prinfgam,nst,drum,gz);

% gam     matrix (gam-dim x K) of gamma parameters, including the base=zero category
%         in columns, the parameters are ordered as in Appendix B of
%         K-state switching models with time-varying transition
%         distributions  Does credit growth signal stronger effects of
%         variables on inflation? (2014)
% Zgam    Vector containing the covariate (without constant)
% sst     row vector containing the state indicator (1...K), including the
%         initial state
% prmgam  matrix (gam-dim x K) of prior mean for the gam parameters
% prinfgam matrix (gam-dim x gam-dim) which contains the prior information
%          for the gam parameters (is the same across states)
% nst     the number of states
% drum    flag, choosing the drum (=1) or the rum (0) sampler
% gz      flag, to simulate state-dependent (=1) effects of the covariate in the
%         transition function

Zdim=size(Zgam,2);
gbase=find(all(gam==0,1));
states=[1:nst];
gampm=[];
gampc=[];

Dt=sst(ones(1,nst),:)'==states(ones(length(sst),1),:);
Dst=kron(Dt,ones(1,Zdim));
if gz
    Zgamt=[kron(ones(1,nst),Zgam).*Dst(1:end-1,:), Dt(1:end-1,:)];
elseif ~gz
    Zgamt=[Zgam, Dt(1:end-1,:)];
end
    

gam_o=gam;


if ~drum
gam_n = mnl_auxmix_beta_unrest(nst,sst(:,2:end)',Zgamt,gam_o,prmgam,prinfgam); %base routine of Sylvia F-S, extended by Sylvia K.
elseif drum
[gam_n,gampm,gampc] = mnl_auxmix_drum(nst-1,sst(:,2:end)',Zgamt,gam_o,prmgam,prinfgam(:,:,ones(1,nst))); %base routine of Sylvia F-S, extended by Sylvia K.
end

gam=gam_n;
